@@ -24,7 +24,8 @@ _DIRECTION_INPUT = True
 _DIRECTION_OUTPUT = False
 
 
-class IOMode():
+class IOMode(object):
+
     """
     >>> mode = IOMode()
     >>> mode.is_input()
@@ -62,4 +63,4 @@ def _test():
     doctest.testmod()
 
 if __name__ == "__main__":
-    _test()
\ No newline at end of file
+    _test()
