@@ -18,6 +18,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
 
+from __future__ import print_function
 import seqdb
 import template
 
@@ -38,7 +39,7 @@ def get_mnemonic(direction, f):
     return mnemonic
 
 
-def format(final, is_input, tracer, controller):
+def format_seq(final, is_input, tracer, controller):
     f = chr(final)
 
     if is_input:
@@ -66,11 +67,11 @@ def _test():
     global _DB
     _DB = {'> ESC N O': 'test'}
 
-    print get_mnemonic('>', 'O')
+    print(get_mnemonic('>', 'O'))
 
-    print get_mnemonic('>', 'A')
+    print(get_mnemonic('>', 'A'))
 
 
 if __name__ == "__main__":
     import doctest
-    doctest.testmod()
\ No newline at end of file
+    doctest.testmod()
