@@ -18,6 +18,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
 
+from __future__ import print_function
 import seqdb
 import template
 
@@ -41,19 +42,20 @@ def get_mnemonic(direction, f):
         mnemonic = '<unknown>'
     return mnemonic
 
-def format(final, is_input, tracer, controller):
+
+def format_seq(final, is_input, tracer, controller):
     """
     >>> _create_mock_db()
     >>> template.enable_color()
-    >>> format(0x42, True, None, None)
+    >>> format_seq(0x42, True, None, None)
     '\\x1b[0;1;36;44m ESC O B \\x1b[0;1;31m\\r\\x1b[30CCursor key(application keypad): down arrow'
     >>> template.disable_color()
-    >>> format(0x42, True, None, None)
+    >>> format_seq(0x42, True, None, None)
     ' ESC O B   Cursor key(application keypad): down arrow'
-    >>> format(0x42, False, None, None)
+    >>> format_seq(0x42, False, None, None)
     ' ESC O B   <unknown>'
     >>> import sys
-    >>> format(0x74, True, sys, None)
+    >>> format_seq(0x74, True, sys, None)
     test
     """
     f = chr(final)
@@ -84,9 +86,10 @@ def _test():
     global _DB
     _DB = {'> ESC O O': 'test'}
 
-    print get_mnemonic('>', 'O')
+    print(get_mnemonic('>', 'O'))
+
+    print(get_mnemonic('>', 'A'))
 
-    print get_mnemonic('>', 'A')
 
 def _create_mock_db():
     global _DB
@@ -108,4 +111,4 @@ def _create_mock_db():
 
 if __name__ == "__main__":
     import doctest
-    doctest.testmod()
\ No newline at end of file
+    doctest.testmod()
