@@ -2,32 +2,26 @@
 # -*- coding: utf-8 -*-
 #
 # ***** BEGIN LICENSE BLOCK *****
-# Copyright (C) 2012-2014, Hayaki Saito 
-# 
-# Permission is hereby granted, free of charge, to any person obtaining a 
-# copy of this software and associated documentation files (the "Software"), 
-# to deal in the Software without restriction, including without limitation 
-# the rights to use, copy, modify, merge, publish, distribute, sublicense, 
-# and/or sell copies of the Software, and to permit persons to whom the 
-# Software is furnished to do so, subject to the following conditions: 
-# 
-# The above copyright notice and this permission notice shall be included in 
-# all copies or substantial portions of the Software. 
-# 
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
-# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
-# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
-# DEALINGS IN THE SOFTWARE. 
-# 
+# Copyright (C) 2012-2014  Hayaki Saito <user@zuse.jp>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
 
-__author__  = "Hayaki Saito (user@zuse.jp)"
-__version__ = "0.2.9"
+__author__ = "Hayaki Saito (user@zuse.jp)"
+__version__ = "0.2.10"
 __license__ = "MIT"
-signature   = '272bd51a6856e85ac4032a83b35779a6'
+signature = 'b87c36758a4c3d666c74490b383f483b'
 
 import sys
 import os
@@ -45,11 +39,13 @@ import logging
 _BUFFER_SIZE = 8192
 _ESC_TIMEOUT = 0.5  # sec
 
+
 ###############################################################################
 #
 # Exceptions
 #
 class NotHandledException(Exception):
+
     ''' thrown when an unknown seqnence is detected '''
 
     def __init__(self, value):
@@ -70,6 +66,7 @@ class NotHandledException(Exception):
 
 
 class ParseException(Exception):
+
     ''' thrown when a parse error is detected '''
 
     def __init__(self, value):
@@ -100,6 +97,7 @@ class ParseException(Exception):
 # - PTY
 #
 class EventObserver:
+
     ''' adapt to event driven ECMA-35/48 parser model '''
 
     def handle_start(self, context):
@@ -132,14 +130,12 @@ class EventObserver:
     def handle_draw(self, context):
         raise NotImplementedError("EventObserver::handle_draw")
 
-    def handle_invalid(self, context, seq):
-        raise NotImplementedError("EventObserver::handle_invalid")
-
     def handle_resize(self, context, row, col):
         raise NotImplementedError("EventObserver::handle_resize")
 
 
 class Scanner:
+
     ''' forward input iterator '''
 
     def __iter__(self):
@@ -152,7 +148,9 @@ class Scanner:
     def continuous_assign(self, value, termenc):
         raise NotImplementedError("Scanner::continuous_assign")
 
+
 class OutputStream:
+
     ''' abstruct TTY output stream '''
 
     def write(self, c):
@@ -163,6 +161,7 @@ class OutputStream:
 
 
 class EventDispatcher:
+
     ''' Dispatch interface of terminal sequence event oriented parser '''
 
     def dispatch_esc(self, prefix, final):
@@ -179,6 +178,7 @@ class EventDispatcher:
 
 
 class Parser:
+
     ''' abstruct Parser '''
 
     def parse(self, context):
@@ -186,6 +186,7 @@ class Parser:
 
 
 class PTY:
+
     ''' abstruct PTY device '''
 
     def fitsize(self):
@@ -215,6 +216,7 @@ class PTY:
 # Simple Parser implementation
 #
 class SimpleParser(Parser):
+
     ''' simple parser, don't parse ESC/CSI/string seqneces '''
 
     class _MockContext:
@@ -274,6 +276,7 @@ class _MockHandler:
 
 
 class DefaultParser(Parser):
+
     ''' parse ESC/CSI/string seqneces '''
 
     def __init__(self):
@@ -582,12 +585,12 @@ class DefaultParser(Parser):
         self.__state = state
 
 
-
 ###############################################################################
 #
 # Scanner implementation
 #
 class DefaultScanner(Scanner):
+
     ''' scan input stream and iterate UCS code points '''
 
     def __init__(self, ucs4=True, termenc=None):
@@ -650,13 +653,14 @@ class DefaultScanner(Scanner):
                 yield ord(x)
 
 
-
 ###############################################################################
 #
 # Handler implementation
 #
 class DefaultHandler(EventObserver):
+
     ''' default handler, pass through all ESC/CSI/string seqnceses '''
+
     def __init__(self):
         pass
 
@@ -916,7 +920,7 @@ class ParseContext(OutputStream, EventDispatcher):
 #
 class DefaultPTY(PTY):
 
-    def __init__(self, term, lang, command, stdin):
+    def __init__(self, term, lang, command, stdin, row=None, col=None):
         self._stdin_fileno = stdin.fileno()
         backup = termios.tcgetattr(self._stdin_fileno)
         self._backup_termios = backup
@@ -924,14 +928,15 @@ class DefaultPTY(PTY):
         if not pid:
             os.environ['TERM'] = term
             os.environ['LANG'] = lang
-            os.execlp('/bin/sh',
-                      '/bin/sh', '-c',
-                      'exec %s' % command)
+            os.execlp('/bin/sh', '/bin/sh', '-c', 'exec %s' % command)
 
         self.__setupterm(self._stdin_fileno)
         self.pid = pid
         self._master = master
 
+        if row and col:
+            self.resize(row, col)
+
     def close(self):
         #self.restore_term()
         try:
@@ -1036,6 +1041,7 @@ class DefaultPTY(PTY):
         #fcntl.ioctl(self._master, termios.TIOCSTART, 0)
         termios.tcflow(self._master, termios.TCOON)
 
+
 class MockParseContext(ParseContext):
 
     def __init__(self):
@@ -1090,7 +1096,7 @@ class Process:
         return self._tty.pid
 
     def is_alive(self):
-        return self._tty is not None 
+        return self._tty is not None
 
     def fileno(self):
         return self._tty.fileno()
@@ -1105,8 +1111,9 @@ class Process:
         self._tty.write(data)
 
     def close(self):
-        if self._tty is not None:
-            self._tty.close()
+        tty = self._tty
+        if tty is not None:
+            tty.close()
             self._tty = None
 
     def end(self):
@@ -1198,23 +1205,35 @@ class Session:
         self._resized = False
         self._process_map = {}
 
+    # deprecated
     def add_subtty(self, term, lang,
                    command, row, col,
                    termenc,
                    inputhandler=DefaultHandler(),
                    outputhandler=DefaultHandler()):
+        return self.create_process(term, lang, command, row, col,
+                                   termenc, inputhandler, outputhandler)
 
-        tty = DefaultPTY(term, lang, command, sys.stdin)
-        tty.resize(row, col)
+    def create_process(self, term, lang,
+                       command, row, col,
+                       termenc,
+                       inputhandler=DefaultHandler(),
+                       outputhandler=DefaultHandler(),
+                       inputparser=DefaultParser(),
+                       outputparser=DefaultParser(),
+                       inputscanner=DefaultScanner(),
+                       outputscanner=DefaultScanner(),
+                       buffering=False):
+
+        tty = DefaultPTY(term, lang, command, sys.stdin, row, col)
         process = Process(tty)
 
         self._init_process(process,
                            termenc,
                            inputhandler, outputhandler,
-                           DefaultParser(), DefaultParser(),
-                           DefaultScanner(), DefaultScanner(),
-                           buffering=False)
-        self.focus_process(process)
+                           inputparser, outputparser,
+                           inputscanner, outputscanner,
+                           buffering=buffering)
         return process
 
     def getactiveprocess(self):
@@ -1232,7 +1251,8 @@ class Session:
     def blur_process(self):
         process = self._mainprocess
         if process.is_alive():
-            logging.info("Switching focus: fileno=%d (main process)" % process.fileno())
+            template = "Switching focus: fileno=%d (main process)"
+            logging.info(template % process.fileno())
             self._input_target.drain()
             self._input_target = process
 
@@ -1350,7 +1370,6 @@ class Session:
                            inputparser, outputparser,
                            inputscanner, outputscanner,
                            buffering)
-        self.focus_process(mainprocess)
 
         self._resized = False
 
@@ -1388,6 +1407,7 @@ class Session:
                       inputscanner,
                       outputscanner,
                       buffering)
+        self.focus_process(process)
 
 
 def _test():
@@ -1400,7 +1420,7 @@ if __name__ == '__main__':
     import inspect
     import hashlib
     import sys
-    
+
     thismodule = sys.modules[__name__]
     md5 = hashlib.md5()
     specs = []
@@ -1418,5 +1438,3 @@ if __name__ == '__main__':
     specs.sort()
     md5.update("".join(specs))
     sys.stdout.write(md5.hexdigest())
-
-
