@@ -21,6 +21,7 @@
 import codecs
 import time
 import logging
+import sys
 
 from tffstub import tff
 import template
@@ -28,7 +29,10 @@ import template
 try:
     from cStringIO import StringIO
 except ImportError:
-    from StringIO import StringIO
+    try:
+        from StringIO import StringIO
+    except ImportError:
+        from io import StringIO
 
 # formatter
 import esc
@@ -40,11 +44,11 @@ import cstr
 from iomode import IOMode
 
 
-class MockController():
+class MockController(object):
     pass
 
 
-class SwitchOnOffTrait():
+class SwitchOnOffTrait(object):
 
     """
     >>> controller = MockController
@@ -114,11 +118,11 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
         prompt = self._io_mode.get_prompt()
-        formatted = esc.format(intermediate,
-                               final,
-                               self._io_mode.is_input(),
-                               self,
-                               self._controller)
+        formatted = esc.format_seq(intermediate,
+                                   final,
+                                   self._io_mode.is_input(),
+                                   self,
+                                   self._controller)
         if not formatted:
             return True
         if self.is_disabled():
@@ -135,12 +139,12 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
         prompt = self._io_mode.get_prompt()
-        formatted = csi.format(parameter,
-                               intermediate,
-                               final,
-                               self._io_mode.is_input(),
-                               self,
-                               self._controller)
+        formatted = csi.format_seq(parameter,
+                                   intermediate,
+                                   final,
+                                   self._io_mode.is_input(),
+                                   self,
+                                   self._controller)
         if self._io_mode.is_input():
             if not parameter and not intermediate:
                 if final == 0x4d:  # 'M'
@@ -171,10 +175,10 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
         prompt = self._io_mode.get_prompt()
-        formatted = ss2.format(final,
-                               self._io_mode.is_input(),
-                               self,
-                               self._controller)
+        formatted = ss2.format_seq(final,
+                                   self._io_mode.is_input(),
+                                   self,
+                                   self._controller)
         if not formatted:
             return True
         if self.is_disabled():
@@ -191,10 +195,10 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
         prompt = self._io_mode.get_prompt()
-        formatted = ss3.format(final,
-                               self._io_mode.is_input(),
-                               self,
-                               self._controller)
+        formatted = ss3.format_seq(final,
+                                   self._io_mode.is_input(),
+                                   self,
+                                   self._controller)
         if not formatted:
             return True
         if self.is_disabled():
@@ -216,11 +220,11 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
             self._buffer.write("\n")
             self.__bufferring = False
         prompt = self._io_mode.get_prompt()
-        formatted = cstr.format(prefix,
-                                value,
-                                self._io_mode.is_input(),
-                                self,
-                                self._controller)
+        formatted = cstr.format_seq(prefix,
+                                    value,
+                                    self._io_mode.is_input(),
+                                    self,
+                                    self._controller)
         if not formatted:
             return True
         self._buffer.write(u"%s  %s\n" % (prompt, formatted))
@@ -235,10 +239,10 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
                 self._xterm_mouse_buffer = None
                 self.handle_xterm_mouse(context, buf)
             return False
-        mnemonic, handled = char.format(c,
-                                        self._io_mode.is_input(),
-                                        self,
-                                        self._controller)
+        mnemonic, handled = char.format_seq(c,
+                                            self._io_mode.is_input(),
+                                            self,
+                                            self._controller)
         if not mnemonic:
             return True
         if self.is_disabled():
@@ -308,13 +312,15 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
     def handle_draw(self, context):
         try:
             self._output.write(self._buffer.getvalue())
-        except IOError, e:
+        except IOError:
+            e = sys.exc_info()[1]
             logging.exception(e)
             time.sleep(0.1)
             self._output.write(self._buffer.getvalue())
         try:
             self._output.flush()
-        except IOError, e:
+        except IOError:
+            e = sys.exc_info()[1]
             logging.exception(e)
             time.sleep(0.1)
             self._output.flush()
